django\_sorcery.management.commands.sorcery\_revision module
============================================================

.. automodule:: django_sorcery.management.commands.sorcery_revision
    :members:
    :undoc-members:
    :show-inheritance:
